# Copyright(C) 2024-2025 Advanced Micro Devices, Inc. All rights reserved.
# SPDX-License-Identifier: MIT
"""
Chat Agent with RAG and file search capabilities.
"""

from gaia.agents.chat.agent import ChatAgent

__all__ = ["ChatAgent"]
